# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/TextAnnotation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/TextAnnotation.proto',
  package='textannotation',
  syntax='proto2',
  serialized_pb=_b('\n\x1dprotobuf/TextAnnotation.proto\x12\x0etextannotation\"\xe2\x02\n\x13TextAnnotationProto\x12\x10\n\x08\x63orpusId\x18\x01 \x02(\t\x12\n\n\x02id\x18\x02 \x02(\t\x12\x0c\n\x04text\x18\x03 \x02(\t\x12\x0e\n\x06tokens\x18\x04 \x03(\t\x12\x37\n\x0ctokenOffsets\x18\x05 \x03(\x0b\x32!.textannotation.TokenOffsetsProto\x12\x30\n\tsentences\x18\x06 \x02(\x0b\x32\x1d.textannotation.SentenceProto\x12(\n\x05views\x18\x07 \x03(\x0b\x32\x19.textannotation.ViewProto\x12G\n\nproperties\x18\x08 \x03(\x0b\x32\x33.textannotation.TextAnnotationProto.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x11TokenOffsetsProto\x12\x0c\n\x04\x66orm\x18\x01 \x02(\t\x12\x17\n\x0fstartCharOffset\x18\x02 \x02(\x05\x12\x15\n\rendCharOffset\x18\x03 \x02(\x05\"R\n\rSentenceProto\x12\x11\n\tgenerator\x18\x01 \x02(\t\x12\x10\n\x05score\x18\x02 \x01(\x01:\x01\x30\x12\x1c\n\x14sentenceEndPositions\x18\x03 \x03(\x05\"N\n\tViewProto\x12\x10\n\x08viewName\x18\x01 \x02(\t\x12/\n\x08viewData\x18\x02 \x03(\x0b\x32\x1d.textannotation.ViewDataProto\"\xc2\x01\n\rViewDataProto\x12\x10\n\x08viewType\x18\x01 \x02(\t\x12\x10\n\x08viewName\x18\x02 \x02(\t\x12\x11\n\tgenerator\x18\x03 \x02(\t\x12\x10\n\x05score\x18\x04 \x01(\x01:\x01\x30\x12\x36\n\x0c\x63onstituents\x18\x05 \x03(\x0b\x32 .textannotation.ConstituentProto\x12\x30\n\trelations\x18\x06 \x03(\x0b\x32\x1d.textannotation.RelationProto\"\xca\x02\n\x10\x43onstituentProto\x12\r\n\x05label\x18\x01 \x02(\t\x12\x10\n\x05score\x18\x02 \x01(\x01:\x01\x30\x12\r\n\x05start\x18\x03 \x02(\x05\x12\x0b\n\x03\x65nd\x18\x04 \x02(\x05\x12\x44\n\nproperties\x18\x05 \x03(\x0b\x32\x30.textannotation.ConstituentProto.PropertiesEntry\x12J\n\rlabelScoreMap\x18\x06 \x03(\x0b\x32\x33.textannotation.ConstituentProto.LabelScoreMapEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x34\n\x12LabelScoreMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\"\xdf\x02\n\rRelationProto\x12\x14\n\x0crelationName\x18\x01 \x02(\t\x12\x10\n\x05score\x18\x02 \x01(\x01:\x01\x30\x12\x16\n\x0esrcConstituent\x18\x03 \x02(\x05\x12\x19\n\x11targetConstituent\x18\x04 \x02(\x05\x12\x41\n\nproperties\x18\x05 \x03(\x0b\x32-.textannotation.RelationProto.PropertiesEntry\x12G\n\rlabelScoreMap\x18\x06 \x03(\x0b\x32\x30.textannotation.RelationProto.LabelScoreMapEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x34\n\x12LabelScoreMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x42G\n/edu.illinois.cs.cogcomp.core.utilities.protobufB\x12TextAnnotationImplP\x00')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_TEXTANNOTATIONPROTO_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='textannotation.TextAnnotationProto.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='textannotation.TextAnnotationProto.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='textannotation.TextAnnotationProto.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=404,
)

_TEXTANNOTATIONPROTO = _descriptor.Descriptor(
  name='TextAnnotationProto',
  full_name='textannotation.TextAnnotationProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='corpusId', full_name='textannotation.TextAnnotationProto.corpusId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='textannotation.TextAnnotationProto.id', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='textannotation.TextAnnotationProto.text', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tokens', full_name='textannotation.TextAnnotationProto.tokens', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tokenOffsets', full_name='textannotation.TextAnnotationProto.tokenOffsets', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sentences', full_name='textannotation.TextAnnotationProto.sentences', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='views', full_name='textannotation.TextAnnotationProto.views', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='textannotation.TextAnnotationProto.properties', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_TEXTANNOTATIONPROTO_PROPERTIESENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=404,
)


_TOKENOFFSETSPROTO = _descriptor.Descriptor(
  name='TokenOffsetsProto',
  full_name='textannotation.TokenOffsetsProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='form', full_name='textannotation.TokenOffsetsProto.form', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='startCharOffset', full_name='textannotation.TokenOffsetsProto.startCharOffset', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='endCharOffset', full_name='textannotation.TokenOffsetsProto.endCharOffset', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=406,
  serialized_end=487,
)


_SENTENCEPROTO = _descriptor.Descriptor(
  name='SentenceProto',
  full_name='textannotation.SentenceProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='generator', full_name='textannotation.SentenceProto.generator', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='textannotation.SentenceProto.score', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sentenceEndPositions', full_name='textannotation.SentenceProto.sentenceEndPositions', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=571,
)


_VIEWPROTO = _descriptor.Descriptor(
  name='ViewProto',
  full_name='textannotation.ViewProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='viewName', full_name='textannotation.ViewProto.viewName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='viewData', full_name='textannotation.ViewProto.viewData', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=573,
  serialized_end=651,
)


_VIEWDATAPROTO = _descriptor.Descriptor(
  name='ViewDataProto',
  full_name='textannotation.ViewDataProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='viewType', full_name='textannotation.ViewDataProto.viewType', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='viewName', full_name='textannotation.ViewDataProto.viewName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='generator', full_name='textannotation.ViewDataProto.generator', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='textannotation.ViewDataProto.score', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='constituents', full_name='textannotation.ViewDataProto.constituents', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='relations', full_name='textannotation.ViewDataProto.relations', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=654,
  serialized_end=848,
)


_CONSTITUENTPROTO_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='textannotation.ConstituentProto.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='textannotation.ConstituentProto.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='textannotation.ConstituentProto.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=404,
)

_CONSTITUENTPROTO_LABELSCOREMAPENTRY = _descriptor.Descriptor(
  name='LabelScoreMapEntry',
  full_name='textannotation.ConstituentProto.LabelScoreMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='textannotation.ConstituentProto.LabelScoreMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='textannotation.ConstituentProto.LabelScoreMapEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1129,
  serialized_end=1181,
)

_CONSTITUENTPROTO = _descriptor.Descriptor(
  name='ConstituentProto',
  full_name='textannotation.ConstituentProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='textannotation.ConstituentProto.label', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='textannotation.ConstituentProto.score', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start', full_name='textannotation.ConstituentProto.start', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end', full_name='textannotation.ConstituentProto.end', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='textannotation.ConstituentProto.properties', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='labelScoreMap', full_name='textannotation.ConstituentProto.labelScoreMap', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CONSTITUENTPROTO_PROPERTIESENTRY, _CONSTITUENTPROTO_LABELSCOREMAPENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=851,
  serialized_end=1181,
)


_RELATIONPROTO_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='textannotation.RelationProto.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='textannotation.RelationProto.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='textannotation.RelationProto.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=404,
)

_RELATIONPROTO_LABELSCOREMAPENTRY = _descriptor.Descriptor(
  name='LabelScoreMapEntry',
  full_name='textannotation.RelationProto.LabelScoreMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='textannotation.RelationProto.LabelScoreMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='textannotation.RelationProto.LabelScoreMapEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1129,
  serialized_end=1181,
)

_RELATIONPROTO = _descriptor.Descriptor(
  name='RelationProto',
  full_name='textannotation.RelationProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relationName', full_name='textannotation.RelationProto.relationName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='textannotation.RelationProto.score', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='srcConstituent', full_name='textannotation.RelationProto.srcConstituent', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='targetConstituent', full_name='textannotation.RelationProto.targetConstituent', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='textannotation.RelationProto.properties', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='labelScoreMap', full_name='textannotation.RelationProto.labelScoreMap', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_RELATIONPROTO_PROPERTIESENTRY, _RELATIONPROTO_LABELSCOREMAPENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1184,
  serialized_end=1535,
)

_TEXTANNOTATIONPROTO_PROPERTIESENTRY.containing_type = _TEXTANNOTATIONPROTO
_TEXTANNOTATIONPROTO.fields_by_name['tokenOffsets'].message_type = _TOKENOFFSETSPROTO
_TEXTANNOTATIONPROTO.fields_by_name['sentences'].message_type = _SENTENCEPROTO
_TEXTANNOTATIONPROTO.fields_by_name['views'].message_type = _VIEWPROTO
_TEXTANNOTATIONPROTO.fields_by_name['properties'].message_type = _TEXTANNOTATIONPROTO_PROPERTIESENTRY
_VIEWPROTO.fields_by_name['viewData'].message_type = _VIEWDATAPROTO
_VIEWDATAPROTO.fields_by_name['constituents'].message_type = _CONSTITUENTPROTO
_VIEWDATAPROTO.fields_by_name['relations'].message_type = _RELATIONPROTO
_CONSTITUENTPROTO_PROPERTIESENTRY.containing_type = _CONSTITUENTPROTO
_CONSTITUENTPROTO_LABELSCOREMAPENTRY.containing_type = _CONSTITUENTPROTO
_CONSTITUENTPROTO.fields_by_name['properties'].message_type = _CONSTITUENTPROTO_PROPERTIESENTRY
_CONSTITUENTPROTO.fields_by_name['labelScoreMap'].message_type = _CONSTITUENTPROTO_LABELSCOREMAPENTRY
_RELATIONPROTO_PROPERTIESENTRY.containing_type = _RELATIONPROTO
_RELATIONPROTO_LABELSCOREMAPENTRY.containing_type = _RELATIONPROTO
_RELATIONPROTO.fields_by_name['properties'].message_type = _RELATIONPROTO_PROPERTIESENTRY
_RELATIONPROTO.fields_by_name['labelScoreMap'].message_type = _RELATIONPROTO_LABELSCOREMAPENTRY
DESCRIPTOR.message_types_by_name['TextAnnotationProto'] = _TEXTANNOTATIONPROTO
DESCRIPTOR.message_types_by_name['TokenOffsetsProto'] = _TOKENOFFSETSPROTO
DESCRIPTOR.message_types_by_name['SentenceProto'] = _SENTENCEPROTO
DESCRIPTOR.message_types_by_name['ViewProto'] = _VIEWPROTO
DESCRIPTOR.message_types_by_name['ViewDataProto'] = _VIEWDATAPROTO
DESCRIPTOR.message_types_by_name['ConstituentProto'] = _CONSTITUENTPROTO
DESCRIPTOR.message_types_by_name['RelationProto'] = _RELATIONPROTO

TextAnnotationProto = _reflection.GeneratedProtocolMessageType('TextAnnotationProto', (_message.Message,), dict(

  PropertiesEntry = _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), dict(
    DESCRIPTOR = _TEXTANNOTATIONPROTO_PROPERTIESENTRY,
    __module__ = 'protobuf.TextAnnotation_pb2'
    # @@protoc_insertion_point(class_scope:textannotation.TextAnnotationProto.PropertiesEntry)
    ))
  ,
  DESCRIPTOR = _TEXTANNOTATIONPROTO,
  __module__ = 'protobuf.TextAnnotation_pb2'
  # @@protoc_insertion_point(class_scope:textannotation.TextAnnotationProto)
  ))
_sym_db.RegisterMessage(TextAnnotationProto)
_sym_db.RegisterMessage(TextAnnotationProto.PropertiesEntry)

TokenOffsetsProto = _reflection.GeneratedProtocolMessageType('TokenOffsetsProto', (_message.Message,), dict(
  DESCRIPTOR = _TOKENOFFSETSPROTO,
  __module__ = 'protobuf.TextAnnotation_pb2'
  # @@protoc_insertion_point(class_scope:textannotation.TokenOffsetsProto)
  ))
_sym_db.RegisterMessage(TokenOffsetsProto)

SentenceProto = _reflection.GeneratedProtocolMessageType('SentenceProto', (_message.Message,), dict(
  DESCRIPTOR = _SENTENCEPROTO,
  __module__ = 'protobuf.TextAnnotation_pb2'
  # @@protoc_insertion_point(class_scope:textannotation.SentenceProto)
  ))
_sym_db.RegisterMessage(SentenceProto)

ViewProto = _reflection.GeneratedProtocolMessageType('ViewProto', (_message.Message,), dict(
  DESCRIPTOR = _VIEWPROTO,
  __module__ = 'protobuf.TextAnnotation_pb2'
  # @@protoc_insertion_point(class_scope:textannotation.ViewProto)
  ))
_sym_db.RegisterMessage(ViewProto)

ViewDataProto = _reflection.GeneratedProtocolMessageType('ViewDataProto', (_message.Message,), dict(
  DESCRIPTOR = _VIEWDATAPROTO,
  __module__ = 'protobuf.TextAnnotation_pb2'
  # @@protoc_insertion_point(class_scope:textannotation.ViewDataProto)
  ))
_sym_db.RegisterMessage(ViewDataProto)

ConstituentProto = _reflection.GeneratedProtocolMessageType('ConstituentProto', (_message.Message,), dict(

  PropertiesEntry = _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONSTITUENTPROTO_PROPERTIESENTRY,
    __module__ = 'protobuf.TextAnnotation_pb2'
    # @@protoc_insertion_point(class_scope:textannotation.ConstituentProto.PropertiesEntry)
    ))
  ,

  LabelScoreMapEntry = _reflection.GeneratedProtocolMessageType('LabelScoreMapEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONSTITUENTPROTO_LABELSCOREMAPENTRY,
    __module__ = 'protobuf.TextAnnotation_pb2'
    # @@protoc_insertion_point(class_scope:textannotation.ConstituentProto.LabelScoreMapEntry)
    ))
  ,
  DESCRIPTOR = _CONSTITUENTPROTO,
  __module__ = 'protobuf.TextAnnotation_pb2'
  # @@protoc_insertion_point(class_scope:textannotation.ConstituentProto)
  ))
_sym_db.RegisterMessage(ConstituentProto)
_sym_db.RegisterMessage(ConstituentProto.PropertiesEntry)
_sym_db.RegisterMessage(ConstituentProto.LabelScoreMapEntry)

RelationProto = _reflection.GeneratedProtocolMessageType('RelationProto', (_message.Message,), dict(

  PropertiesEntry = _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), dict(
    DESCRIPTOR = _RELATIONPROTO_PROPERTIESENTRY,
    __module__ = 'protobuf.TextAnnotation_pb2'
    # @@protoc_insertion_point(class_scope:textannotation.RelationProto.PropertiesEntry)
    ))
  ,

  LabelScoreMapEntry = _reflection.GeneratedProtocolMessageType('LabelScoreMapEntry', (_message.Message,), dict(
    DESCRIPTOR = _RELATIONPROTO_LABELSCOREMAPENTRY,
    __module__ = 'protobuf.TextAnnotation_pb2'
    # @@protoc_insertion_point(class_scope:textannotation.RelationProto.LabelScoreMapEntry)
    ))
  ,
  DESCRIPTOR = _RELATIONPROTO,
  __module__ = 'protobuf.TextAnnotation_pb2'
  # @@protoc_insertion_point(class_scope:textannotation.RelationProto)
  ))
_sym_db.RegisterMessage(RelationProto)
_sym_db.RegisterMessage(RelationProto.PropertiesEntry)
_sym_db.RegisterMessage(RelationProto.LabelScoreMapEntry)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n/edu.illinois.cs.cogcomp.core.utilities.protobufB\022TextAnnotationImplP\000'))
_TEXTANNOTATIONPROTO_PROPERTIESENTRY.has_options = True
_TEXTANNOTATIONPROTO_PROPERTIESENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_CONSTITUENTPROTO_PROPERTIESENTRY.has_options = True
_CONSTITUENTPROTO_PROPERTIESENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_CONSTITUENTPROTO_LABELSCOREMAPENTRY.has_options = True
_CONSTITUENTPROTO_LABELSCOREMAPENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_RELATIONPROTO_PROPERTIESENTRY.has_options = True
_RELATIONPROTO_PROPERTIESENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_RELATIONPROTO_LABELSCOREMAPENTRY.has_options = True
_RELATIONPROTO_LABELSCOREMAPENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
# @@protoc_insertion_point(module_scope)
